@@ -3,18 +3,41 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.05_08';
+our $VERSION = '0.07_01';
 
+my %VALID_IMPORT_OPT = map{ $_ => 1 } qw( base mixin );
 sub import{
+    my ( $self, @opts ) = @_;
+    @opts = %{ $opts[0] } if ref $opts[0] eq 'HASH';
+    
+    # import option
+    my $import_opt = {};
+    while( my ( $opt, $val ) = splice( @opts, 0, 2 ) ){
+        croak "Invalid import option '$opt'" unless $VALID_IMPORT_OPT{ $opt };
+        $import_opt->{ $opt } = $val;
+    }
+    
     my $caller_pkg = caller;
     
+    # export function
     {
         # export function
         no strict 'refs';
         *{ "${caller_pkg}::ac" } = \&Simo::ac;
-        
-        # caller inherit Simo
-        push @{ "${caller_pkg}::ISA" }, __PACKAGE__;
+    }
+    
+    # inherit base class
+    my @inherit_classes = _SIMO_get_inherit_classes( $import_opt );
+    if( @inherit_classes ){
+        eval "package $caller_pkg;" .
+             "use base \@inherit_classes;";
+        if( $@ ){ $@ =~ s/\s+at .+$//; croak $@ }
+    }
+    
+    # inherit Simo
+    {
+        no strict 'refs';
+        push @{ "${caller_pkg}::ISA" }, 'Simo';
     }
 
     # auto strict and warnings
@@ -22,6 +45,27 @@ sub import{
     warnings->import;
 }
 
+sub _SIMO_get_inherit_classes{
+    my $import_opt = shift;
+    my @base_classes;
+    
+    my @inherit_classes;
+    if( my $base = $import_opt->{ base } ){
+        push @inherit_classes,
+            ref $base eq 'ARRAY' ? @{ $base } : $base;
+    }
+    
+    if( my $mixin = $import_opt->{ mixin } ){
+        push @inherit_classes,
+            ref $mixin eq 'ARRAY' ? @{ $mixin } : $mixin;
+    }
+    
+    foreach my $inherit_class( @inherit_classes ){
+        croak "Invalid class name '$inherit_class'" unless $inherit_class =~ /^(\w+::)*\w+$/;
+    }
+    return @inherit_classes;
+}
+
 sub new{
     my ( $proto, @args ) = @_;
 
@@ -86,6 +130,46 @@ sub set_attrs{
     return $self;
 }
 
+# run methods
+sub run_methods{
+    my ( $self, @method_or_args_list ) = @_;
+    
+    my $method_infos = $self->_SIMO_parse_run_methods_args( @method_or_args_list );
+    while( my $method_info = shift @{ $method_infos } ){
+        my ( $method, $args ) = @{ $method_info }{ qw( name args ) };
+        
+        if( @{ $method_infos } ){
+            $self->$method( @{ $args } );
+        }
+        else{
+            return wantarray ? ( $self->$method( @{ $args } ) ) :
+                                 $self->$method( @{ $args } );
+        }
+    }
+}
+
+sub _SIMO_parse_run_methods_args{
+    my ( $self, @method_or_args_list ) = @_;
+    
+    my $method_infos = [];
+    while( my $method_or_args = shift @method_or_args_list ){
+        croak "$method_or_args is bad. Method name must be string and args must be array ref"
+            if ref $method_or_args;
+        
+        my $method = $method_or_args;
+        croak "$method is not exist" unless $self->can( $method );
+        
+        my $method_info = {};
+        $method_info->{ name } = $method;
+        $method_info->{ args } = ref $method_or_args_list[0] eq 'ARRAY' ?
+                                 shift @method_or_args_list :
+                                 [];
+        
+        push @{ $method_infos }, $method_info;
+    }
+    return $method_infos;
+}
+
 
 # create accessor
 sub ac(@){
@@ -107,7 +191,9 @@ sub _SIMO_process{
     # check and rearrange accessor option;
     my $ac_opt = {};
     
-    $ac_opt->{ default } = shift if @_ % 2;
+    $ac_opt->{ default } = shift if @_ % 2; 
+        # ( Unnamed default option is is now not recommended. this will be deleted in future 2019/01/01 )
+    
     my $hook_options_exist = {};
     
     while( my( $key, $val ) = splice( @_, 0, 2 ) ){
@@ -190,6 +276,7 @@ sub _SIMO_create_accessor{
     
     if( defined $ac_opt->{ set_hook } ){
         # set_hook option
+        #( set_hook option is is now not recommended. this option will be deleted in future 2019/01/01 )
         $e .=
         qq/        eval{ \$val = \$ac_opt->{ set_hook }->( \$self, \$val ) };\n/ .
         qq/        Carp::confess( \$@ ) if \$@;\n\n/;
@@ -260,6 +347,7 @@ sub _SIMO_create_accessor{
     
     if( defined $ac_opt->{ get_hook } ){
         # get_hook option
+        # ( get_hook option is is now not recommended. this option will be deleted in future 2019/01/01 )
         $e .=
         qq/    eval{ \$ret = \$ac_opt->{ get_hook }->( \$self, \$ret ) };\n/ .
         qq/    Carp::confess( \$@ ) if \$@;\n/;
@@ -291,7 +379,7 @@ Simo - Very simple framework for Object Oriented Perl.
 
 =head1 VERSION
 
-Version 0.05_08
+Version 0.07_01
 
 =cut
 
@@ -535,18 +623,6 @@ If you use hash_force option, you convert list to hash ref
 
 =cut
 
-=head3 set_hook option
-
-set_hook option is now not recommended. this option will be deleted in future 2019/01/01
-
-=cut
-
-=head3 get_hook option
-
-get_hook option is now not recommended. this option will be deleted in future 2019/01/01
-
-=cut
-
 =head2 Order of constrain, filter and trigger
 
 =over 4
@@ -584,6 +660,8 @@ You can get old value when you use accessor as setter.
 
 ac is exported. This is used by define accessor. 
 
+=head1 METHOD
+
 =head2 new
 
 orveridable new method.
@@ -607,6 +685,20 @@ or
 return value is $self. so method chaine is available
 
     $book->set_attrs( title => 'Simple OO', author => 'kimoto' )->some_method;
+    
+=head2 run_methods
+
+this excute some methods continuously.
+
+    my $result = $book_list->run_methods(
+        'select' => [ type => 'Commic' ],
+        'sort' => [ 'desc' },
+        'get_result'
+    );
+    
+args must be array ref. You can omit args.
+
+You can get last method return value in scalar context or list context.
 
 =head1 MORE TECHNIQUES
 
